# This class is used to define custom checks for hosts or groups of hosts
class net::naemon_monitor_config {

  nagioscfg::service {'check_baas2-restore-status':
      host_name      => ['baas2-restoretest-prod-1.sunet.se'],
      check_command  => "check_nrpe!check_baas2-restore-status",
      description    => 'BaaS2 restore validation',
      action_url     => 'https://wiki.sunet.se/display/sunetops/BaaS2+-+Monitoring',
      notes          => 'This check validates that restore from BaaS2 works as intended, see action URL for more info.',
      contact_groups => ['alerts']
  }

  $public_hosts = ['zoom-saas-idp-proxy.sunet.se']
  nagioscfg::host {$public_hosts: single_ip => true }

  nagioscfg::command {'check_website':
      command_line   => "/usr/lib/nagios/plugins/check_http -H '\$HOSTNAME\$' -S -u '\$ARG1\$' -s '\$ARG2\$'"
  }

  $hosts_zoom = ['zoomproxy-tug-prod-1.sunet.se', 'zoomproxy-sto1-prod-1.sunet.se', 'zoom-saas-idp-proxy.sunet.se']
  $hosts_zoom.each |$host|{
    nagioscfg::service {"check_satosa_health${host}":
      host_name      => ["${host}"],
      check_command  => "check_website!https://${host}/healthcheck!ok",
      description    => "SATOSA running in ${host}",
      contact_groups => ['alerts'],
    }
  }
}
